==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/plugins/experience/reducers/deleteExperience.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/plugins/experience/reducers/deleteExperience", ['module', 'exports', 'require', './utils'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = void 0;

    var _utils = require("./utils");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function deleteExperienceReducer(state, payload) {
      var nextState = state;
      var segmentsExperienceId = payload.segmentsExperienceId;
      nextState = (0, _utils.removeLayoutDataItemById)(nextState, segmentsExperienceId);
      nextState = (0, _utils.deleteExperienceById)(nextState, segmentsExperienceId);
      return nextState;
    }

    var _default = deleteExperienceReducer;
    exports["default"] = _default;
    //# sourceMappingURL=deleteExperience.js.map
  }
});
//# sourceMappingURL=deleteExperience.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/plugins/experience/reducers/deleteExperience.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/plugins/experience/reducers/deleteExperience", ['module', 'exports', 'require', './utils'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;

    var _utils = require("./utils");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function deleteExperienceReducer(state, payload) {
      var nextState = state;
      var segmentsExperienceId = payload.segmentsExperienceId;
      nextState = (0, _utils.removeLayoutDataItemById)(nextState, segmentsExperienceId);
      nextState = (0, _utils.deleteExperienceById)(nextState, segmentsExperienceId);
      return nextState;
    }

    var _default = deleteExperienceReducer;
    exports.default = _default;
    //# sourceMappingURL=deleteExperience.js.map
  }
});
//# sourceMappingURL=deleteExperience.js.map
